Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1041)

Unified Diff: content/browser/loader/upload_data_stream_builder.h

Issue 2954343005: Merge ResourceRequestBodyImpl and ResourceRequestBody. (Closed)
Patch Set: Remove comment Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/loader/upload_data_stream_builder.h
diff --git a/content/browser/loader/upload_data_stream_builder.h b/content/browser/loader/upload_data_stream_builder.h
index 9b2bfcbf275d03d0aac77461228505bd71a42666..fae5f3a70cafde9a3bd9d857fd374f12b45e36c2 100644
--- a/content/browser/loader/upload_data_stream_builder.h
+++ b/content/browser/loader/upload_data_stream_builder.h
@@ -27,7 +27,7 @@ class BlobStorageContext;
namespace content {
-class ResourceRequestBodyImpl;
+class ResourceRequestBody;
class CONTENT_EXPORT UploadDataStreamBuilder {
public:
@@ -35,14 +35,14 @@ class CONTENT_EXPORT UploadDataStreamBuilder {
//
// If |body| contains any blob references, the caller is responsible for
// making sure them outlive the returned value of UploadDataStream. We do this
// by binding the BlobDataHandles of them to ResourceRequestBodyImpl in
// ResourceDispatcherHostImpl::BeginRequest().
//
// |file_system_context| is used to create a FileStreamReader for files with
// filesystem URLs. |file_task_runner| is used to perform file operations
// when the data gets uploaded.
static std::unique_ptr<net::UploadDataStream> Build(
- ResourceRequestBodyImpl* body,
+ ResourceRequestBody* body,
storage::BlobStorageContext* blob_context,
storage::FileSystemContext* file_system_context,
base::SingleThreadTaskRunner* file_task_runner);
@@ -35,14 +35,14 @@ class CONTENT_EXPORT UploadDataStreamBuilder {
// If |body| contains any blob references, the caller is responsible for
// making sure them outlive the returned value of UploadDataStream. We do this
- // by binding the BlobDataHandles of them to ResourceRequestBodyImpl in
+ // by binding the BlobDataHandles of them to ResourceRequestBody in
// ResourceDispatcherHostImpl::BeginRequest().
//
« no previous file with comments | « content/browser/loader/resource_request_info_impl.cc ('k') | content/browser/loader/upload_data_stream_builder.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698